SampledRankBasedEvaluator
=========================

.. currentmodule:: pykeen.evaluation

.. autoclass:: SampledRankBasedEvaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SampledRankBasedEvaluator.process_scores_

   .. rubric:: Methods Documentation

   .. automethod:: process_scores_
